==> jc-1.4.0.tar.gz: soot/grimp/internal/GNewMultiArrayExpr.h <==
// public class soot.grimp.internal.GNewMultiArrayExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c7ab12038a9c0bc6 soot_grimp_internal_GNewMultiArrayExpr
// @dep_class f1308ce4deac7989 soot_jimple_internal_AbstractNewMultiArrayExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNewMultiArrayExpr

#include "soot/jimple/internal/AbstractNewMultiArrayExpr.h"

#ifndef _JC_soot_grimp_internal_GNewMultiArrayExpr_H_
#define _JC_soot_grimp_internal_GNewMultiArrayExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_ArrayType$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GNewMultiArrayExpr$sub_refs	_jc_soot_grimp_internal_GNewMultiArrayExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GNewMultiArrayExpr$sub_nonrefs	_jc_soot_grimp_internal_GNewMultiArrayExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GNewMultiArrayExpr$refs	_jc_soot_grimp_internal_GNewMultiArrayExpr$refs;
typedef struct _jc_soot_grimp_internal_GNewMultiArrayExpr$nonrefs	_jc_soot_grimp_internal_GNewMultiArrayExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GNewMultiArrayExpr$object	_jc_soot_grimp_internal_GNewMultiArrayExpr$object;

typedef const struct _jc_soot_grimp_internal_GNewMultiArrayExpr$vmethods	_jc_soot_grimp_internal_GNewMultiArrayExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GNewMultiArrayExpr$vtable	_jc_soot_grimp_internal_GNewMultiArrayExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GNewMultiArrayExpr$vtype	_jc_soot_grimp_internal_GNewMultiArrayExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GNewMultiArrayExpr$method$_init$6d5b986214f5a4a4(_jc_env *, struct _jc_soot_grimp_internal_GNewMultiArrayExpr$object *, struct _jc_soot_ArrayType$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GNewMultiArrayExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GNewMultiArrayExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GNewMultiArrayExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GNewMultiArrayExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GNewMultiArrayExpr$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GNewMultiArrayExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractNewMultiArrayExpr$vmethods	soot_jimple_internal_AbstractNewMultiArrayExpr;
	_jc_soot_grimp_internal_GNewMultiArrayExpr$vmethods	soot_grimp_internal_GNewMultiArrayExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GNewMultiArrayExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GNewMultiArrayExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GNewMultiArrayExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GNewMultiArrayExpr$refs {
    _jc_soot_grimp_internal_GNewMultiArrayExpr$sub_refs	soot_grimp_internal_GNewMultiArrayExpr;
    _jc_soot_jimple_internal_AbstractNewMultiArrayExpr$sub_refs	soot_jimple_internal_AbstractNewMultiArrayExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GNewMultiArrayExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GNewMultiArrayExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractNewMultiArrayExpr$sub_nonrefs	soot_jimple_internal_AbstractNewMultiArrayExpr;
    _jc_soot_grimp_internal_GNewMultiArrayExpr$sub_nonrefs	soot_grimp_internal_GNewMultiArrayExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GNewMultiArrayExpr$object {
	_jc_soot_grimp_internal_GNewMultiArrayExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GNewMultiArrayExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GNewMultiArrayExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GNewMultiArrayExpr$vtype _jc_soot_grimp_internal_GNewMultiArrayExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GNewMultiArrayExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GNewMultiArrayExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GNewMultiArrayExpr_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GNewMultiArrayExpr.h <==
// public class soot.grimp.internal.GNewMultiArrayExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c7ab12038a9c0bc6 soot_grimp_internal_GNewMultiArrayExpr
// @dep_class f1308ce4deac7989 soot_jimple_internal_AbstractNewMultiArrayExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNewMultiArrayExpr

#include "soot/jimple/internal/AbstractNewMultiArrayExpr.h"

#ifndef _JC_soot_grimp_internal_GNewMultiArrayExpr_H_
#define _JC_soot_grimp_internal_GNewMultiArrayExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_ArrayType$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GNewMultiArrayExpr$sub_refs	_jc_soot_grimp_internal_GNewMultiArrayExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GNewMultiArrayExpr$sub_nonrefs	_jc_soot_grimp_internal_GNewMultiArrayExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GNewMultiArrayExpr$refs	_jc_soot_grimp_internal_GNewMultiArrayExpr$refs;
typedef struct _jc_soot_grimp_internal_GNewMultiArrayExpr$nonrefs	_jc_soot_grimp_internal_GNewMultiArrayExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GNewMultiArrayExpr$object	_jc_soot_grimp_internal_GNewMultiArrayExpr$object;

typedef const struct _jc_soot_grimp_internal_GNewMultiArrayExpr$vmethods	_jc_soot_grimp_internal_GNewMultiArrayExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GNewMultiArrayExpr$vtable	_jc_soot_grimp_internal_GNewMultiArrayExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GNewMultiArrayExpr$vtype	_jc_soot_grimp_internal_GNewMultiArrayExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GNewMultiArrayExpr$method$_init$6d5b986214f5a4a4(_jc_env *, struct _jc_soot_grimp_internal_GNewMultiArrayExpr$object *, struct _jc_soot_ArrayType$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GNewMultiArrayExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GNewMultiArrayExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GNewMultiArrayExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GNewMultiArrayExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GNewMultiArrayExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GNewMultiArrayExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractNewMultiArrayExpr$vmethods	soot_jimple_internal_AbstractNewMultiArrayExpr;
	_jc_soot_grimp_internal_GNewMultiArrayExpr$vmethods	soot_grimp_internal_GNewMultiArrayExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GNewMultiArrayExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GNewMultiArrayExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GNewMultiArrayExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GNewMultiArrayExpr$refs {
    _jc_soot_grimp_internal_GNewMultiArrayExpr$sub_refs	soot_grimp_internal_GNewMultiArrayExpr;
    _jc_soot_jimple_internal_AbstractNewMultiArrayExpr$sub_refs	soot_jimple_internal_AbstractNewMultiArrayExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GNewMultiArrayExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GNewMultiArrayExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractNewMultiArrayExpr$sub_nonrefs	soot_jimple_internal_AbstractNewMultiArrayExpr;
    _jc_soot_grimp_internal_GNewMultiArrayExpr$sub_nonrefs	soot_grimp_internal_GNewMultiArrayExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GNewMultiArrayExpr$object {
	_jc_soot_grimp_internal_GNewMultiArrayExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GNewMultiArrayExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GNewMultiArrayExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GNewMultiArrayExpr$vtype _jc_soot_grimp_internal_GNewMultiArrayExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GNewMultiArrayExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GNewMultiArrayExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GNewMultiArrayExpr_H_ */
